possSpells.fnc: Get all of a word's possible spellings.
Description
For every word in the input list, the function will return the number of possible spellings as well as the actual spellings.
Usage
possSpells.fnc(words)
Arguments
words
Note that the words have to be in Sampa phonetic notation. Also note that the Sampa symbols left curly bracket and @ prime (where prime is an actual prime symbol) have to replaced by ZZZ and RRR respectively. Further note that the individual phonemes of a word have to be separated by an underscore _.
Details
The function returns a vector containing all of a word's possible spellings.
# create a list of wordsword.list<-c("d_ZZZ_s_t_I_t",
"j_u_l_o",
"f_A_m")
(as.matrix(word.list))
# process the wordsx<-possSpells.fnc(word.list)
(matrix(x,ncol=4,nrow=29))